@@ -9,7 +9,7 @@ test_that("editrules can derive the correct info from a matrix",{
 	#			, dimnames=list(c("a", "b"), c("x","y", "z"))
 				)
    ei <- editrules(mat)
-   expect_equal(ei$edit, c("a == 2*b", "2*a + c == 0"))
+   expect_equal(ei$edit, c("x1 == 2*x2", "2*x1 + x3 == 0"))
    
    mat <- matrix( c( 1,-2
                    , 2, 0
@@ -23,13 +23,14 @@ test_that("editrules can derive the correct info from a matrix",{
    expect_equal(ei$edit, c("x == 2*y", "2*x == 0"))
 })
 
-test_that("getC works",{
+test_that("getb works",{
    cond <- c( "x + y > 2"
             , "y < 10"
             )
-   E <- editmatrix(cond)
-   C <- getC(E)
-   expect_equal(C, c(e1=2,e2=10))
+   E <- editmatrix(cond, FALSE)
+   b <- getb(E)
+  
+   expect_equal(b, c(e1=2,e2=10))
 })
 
 test_that("getOps works",{
@@ -39,7 +40,7 @@ test_that("getOps works",{
             , "y <= 10"
             , "y >= 10"
             )
-   E <- editmatrix(cond)
+   E <- editmatrix(cond, FALSE)
    ops <- getOps(E)
-   expect_equal(as.character(ops), c(">","<","==","<=",">="))
-})
\ No newline at end of file
+   expect_equivalent(ops, c(">","<","==","<=",">="))
+})
